==> 0.0.2.tar.gz: lib/components/senior_top_bar.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_tokens/tokens/senior_typography.dart';

abstract class SeniorTopBarTheme {
  static Color getItemsColor({ required Brightness theme }) {
    return SeniorColors.neutralColor800;
  }
}

class SeniorTopBarAction {
  final IconData icon;
  final String? tooltip;
  final VoidCallback onPressed;

  SeniorTopBarAction({
    required this.icon,
    this.tooltip,
    required this.onPressed,
  });
}

abstract class SeniorTopBar extends StatelessWidget {
  final Widget title;
  final SeniorTopBarAction? leading;
  final List<SeniorTopBarAction>? actions;

  SeniorTopBar({
    required Key key,
    required this.title,
    this.leading,
    this.actions,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Theme(
      data: ThemeData(
        primaryTextTheme: TextTheme(
          headline6: SeniorTypography.getTextStyle(
            token: SeniorTypographyTokens.h4,
            color: SeniorTopBarTheme.getItemsColor(theme: theme),
          ),
        ),
      ),
      child: AppBar(
        primary: true,
        backgroundColor: Colors.transparent,
        shadowColor: Colors.transparent,
        leading: leading != null
            ? IconButton(
                icon: FaIcon(this.leading!.icon),
                tooltip: this.leading!.tooltip,
                onPressed: this.leading!.onPressed,
                iconSize: SeniorTypographyIconSize.h4,
                color: SeniorTopBarTheme.getItemsColor(theme: theme),
              )
            : null,
        title: this.title,
        actions: this.actions?.map(
              (action) => IconButton(
                icon: FaIcon(action.icon),
                tooltip: action.tooltip,
                onPressed: action.onPressed,
                iconSize: SeniorTypographyIconSize.h4,
                color: SeniorTopBarTheme.getItemsColor(theme: theme),
              ),
            ).toList(),
      ),
    );
  }
}

class SeniorTopBarHome extends SeniorTopBar {
  SeniorTopBarHome({
    required Key key,
    required String titleImagePath,
    SeniorTopBarAction? leading,
    List<SeniorTopBarAction>? actions,
  }) : super(
    key: key,
    title: Image.asset(titleImagePath),
    leading: leading,
    actions: actions,
  );
}

class SeniorTopBarPage extends SeniorTopBar {
  SeniorTopBarPage({
    required Key key,
    required String title,
    required SeniorTopBarAction leading,
    required List<SeniorTopBarAction> actions,
  }) : super(
    key: key,
    title: Text(title),
    leading: leading,
    actions: actions
  );
}

==> 0.2.0.tar.gz: lib/components/senior_top_bar.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorTopBarTheme {
  SeniorTopBarTheme._();

  static Color getItemsColor({ required Brightness theme }) {
    return SeniorColors.neutralColor800;
  }
}

class SeniorTopBarAction {
  final IconData icon;
  final String? tooltip;
  final Function() onPressed;

  const SeniorTopBarAction({
    required this.icon,
    this.tooltip,
    required this.onPressed,
  });
}

abstract class SeniorTopBar extends StatelessWidget implements PreferredSizeWidget {
  final Widget title;
  final SeniorTopBarAction? leading;
  final List<SeniorTopBarAction>? actions;

  const SeniorTopBar({
    Key? key,
    required this.title,
    this.leading,
    this.actions,
  }) : super(key: key);

  @override
  Size get preferredSize => const Size.fromHeight(100.0);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return Theme(
      data: ThemeData(
        primaryTextTheme: TextTheme(
          headline6: SeniorTypography.getTextStyle(
            token: SeniorTypographyTokens.h4,
            color: SeniorTopBarTheme.getItemsColor(theme: theme),
          ),
        ),
      ),
      child: AppBar(
        primary: true,
        backgroundColor: Colors.transparent,
        shadowColor: Colors.transparent,
        leading: leading != null
            ? IconButton(
                icon: FaIcon(this.leading!.icon),
                tooltip: this.leading!.tooltip,
                onPressed: this.leading!.onPressed,
                iconSize: SeniorTypographyIconSize.h4,
                color: SeniorTopBarTheme.getItemsColor(theme: theme),
              )
            : null,
        title: this.title,
        actions: this.actions?.map(
              (action) => IconButton(
                icon: FaIcon(action.icon),
                tooltip: action.tooltip,
                onPressed: action.onPressed,
                iconSize: SeniorTypographyIconSize.h4,
                color: SeniorTopBarTheme.getItemsColor(theme: theme),
              ),
            ).toList(),
      ),
    );
  }
}

class SeniorTopBarHome extends SeniorTopBar {
  SeniorTopBarHome({
    Key? key,
    required String titleImagePath,
    SeniorTopBarAction? leading,
    List<SeniorTopBarAction>? actions,
  }) : super(
    key: key,
    title: Image.asset(titleImagePath),
    leading: leading,
    actions: actions,
  );
}

class SeniorTopBarPage extends SeniorTopBar {
  SeniorTopBarPage({
    Key? key,
    required String title,
    required SeniorTopBarAction leading,
    required List<SeniorTopBarAction> actions,
  }) : super(
    key: key,
    title: Text(title),
    leading: leading,
    actions: actions
  );
}
